@@ -84,12 +84,17 @@ class SimplRun(DjangoObjectType):
         description="List of Auth0 IDs for players that have not been assigned to a "
         "run yet.",
     )
+    players_inactive = graphene.List(
+        graphene.ID,
+        description="List of Auth0 IDs for players that are inactive.",
+    )
     player_count = graphene.Int()
     managers = graphene.List(
         graphene.ID, description="List of Auth0 IDs for managers of this run"
     )
     instances = graphene.List(SimplInstance)
     status = graphene.Field(RunStatus)
+    game_id = graphene.UUID()
     class_id = graphene.ID()
     class_name = graphene.Field(graphene.String)
     continuous_open = graphene.Boolean()
@@ -115,6 +120,11 @@ class SimplRun(DjangoObjectType):
         users = User.objects.filter(player__run=obj, player__character=None)
         return utils.get_auth0_ids(*users)
 
+    @staticmethod
+    def resolve_players_inactive(obj, info):
+        users = obj.player_set.filter(inactive=True).values_list("user")
+        return utils.get_auth0_ids(*users)
+
     @staticmethod
     def resolve_player_count(obj, info):
         return obj.player_set.exclude(user=None).count()
@@ -127,6 +137,11 @@ class SimplRun(DjangoObjectType):
     def resolve_instances(obj, info):
         return Instance._default_manager.filter(run=obj)
 
+    @staticmethod
+    def resolve_game_id(obj, info):
+        if obj.game:
+            return obj.game.experience_id
+
     @staticmethod
     def resolve_class_id(obj, info):
         if obj.simpl_class:
@@ -248,3 +263,14 @@ class SimplGame(DjangoObjectType):
     @staticmethod
     def resolve_id(obj, info):
         return obj.experience_id
+
+
+class SimplClass(DjangoObjectType):
+    """
+    A Simpl class
+    """
+
+    class Meta:
+        model = models.Class
+        skip_registry = True
+        fields = ["id", "name"]
